Eddystone test using modified DAL

Dependencies:   BLE_API mbed-dev-bin nRF51822

Dependents:   microbit-eddystone

Fork of microbit-dal by Lancaster University

Revision:
52:3db7b4d64316
Parent:
51:9198e7bb83dc
Child:
69:b62f231e51ce
--- a/inc/types/ManagedString.h	Wed Jul 13 12:18:30 2016 +0100
+++ b/inc/types/ManagedString.h	Wed Jul 13 12:18:31 2016 +0100
@@ -300,9 +300,10 @@
     ManagedString substring(int16_t start, int16_t length);
 
     /**
-      * Concatenates this string with the one provided.
+      * Concatenates two strings.
       *
       * @param s The ManagedString to concatenate.
       *
       * @return a new ManagedString representing the joined strings.
       *
@@ -314,7 +315,7 @@
       * display.scroll(s + p) // scrolls "abcdefgh"
       * @endcode
       */
-    ManagedString operator+ (const ManagedString& s);
+    friend ManagedString operator+ (const ManagedString& lhs, const ManagedString& rhs);
 
     /**
       * Provides a character value at a given position in the string, indexed from zero.
@@ -300,9 +300,10 @@
       *
-      * @param s The ManagedString to concatenate.
+      * @param lhs The first ManagedString to concatenate.
+      * @param rhs The second ManagedString to concatenate.
       *
       * @return a new ManagedString representing the joined strings.